==> flutter_payumoney_plugin-0.0.15.tar.gz: ios/Classes/PayUMoneyHelper.swift <==
//
//  PayUMoneyHelper.swift
//  PayUMoney Demo
//
//  Created by Akash Patel on 12/04/20.
//  Copyright © 2020 Akash Patel. All rights reserved.
//

import Foundation
import UIKit
import PayUMoneyCoreSDK
import PayUCustomBrowser
import PlugNPlay
import CommonCrypto

public func checkiOSLog(_ completion : @escaping (_ returnString : String)->Void) {
    DispatchQueue.main.asyncAfter(deadline: .now() + 2.0) {
        completion("checkiOSLog invoked")
    }
}

public func checkiOSReturn() -> String {
    return "checkiOSReturn"
}

public func startPaymentWithAmount(_ amount : String, userName : String, email: String, contactNo : String, fromName: String, gNumber : String, isProduction : Bool, fromController : UIViewController, completion : @escaping (_ responseObject : [String : Any], _ transactionID : String, _ error : Error?)->Void) {
    
    let txnID = Int64(Date().timeIntervalSince1970 * 1000).description
    
    //Proceed with paymentprint(responseParam)
    let txnParam = PUMTxnParam.init()
    txnParam.phone = contactNo
    txnParam.email = email
    txnParam.amount = amount
    txnParam.environment = isProduction ? .production : .test
    txnParam.firstname = "\(userName) -\(gNumber)"
    txnParam.key = "cIzp948M"
    txnParam.merchantid = "5662740"
    txnParam.txnID = txnID
    txnParam.surl = "https://www.payumoney.com/mobileapp/payumoney/success.php"
    txnParam.furl = "https://www.payumoney.com/mobileapp/payumoney/failure.php"
    txnParam.productInfo = fromName
    txnParam.udf1 = "Charged by Gujarat State Pharmacy Council"
    txnParam.udf2 = "Charged amount \(amount)"
    txnParam.udf3 = ""
    txnParam.udf4 = ""
    txnParam.udf5 = ""
    txnParam.udf6 = ""
    txnParam.udf7 = ""
    txnParam.udf8 = ""
    txnParam.udf9 = ""
    txnParam.udf10 = ""
    
    //cIzp948M|txnID123|\(self.textFieldAmount?.text ?? "1")|iPhone7|Akash|akashpatel116@gmail.com|||||||||||salt.
    //key|txnid|amount|productinfo|firstname|email|udf1|udf2|udf3|udf4|udf5||||||qoiFxDW2A2.
   // let createdHash = "cIzp948M|\(txnID)|\(amount)|\(UIDevice.current.model) with \(UIDevice.current.systemVersion)|\(userName)|\(email)|Charged by Gujarat State Pharmacy Council|Charged amount \(amount)|||||||||qoiFxDW2A2"
    let createdHash = "cIzp948M|\(txnID)|\(amount)|\(fromName)|\(userName) -\(gNumber)|\(email)|Charged by Gujarat State Pharmacy Council|Charged amount \(amount)|||||||||qoiFxDW2A2"
    //"sha512(cIzp948M|txnID123|\(self.textFieldAmount?.text ?? "1")|iPhone7|Akash|akashpatel116@gmail.com|abc|5|||||||||qoiFxDW2A2)"
    txnParam.hashValue = createHashFor(source: createdHash)
    
    //key|txnid|amount|productinfo|firstname|email|udf1|udf2|udf3|udf4|udf5||||||qoiFxDW2A2"
    
    PlugNPlay.presentPaymentViewController(withTxnParams: txnParam, on: fromController) { (responseParam, error, anyObject) in
        print(responseParam)
        //self.lblTransactionID?.text = (responseParam as? NSDictionary)?.description
        print(error)
        print(anyObject)
        let transactionID = ((responseParam as? [String : Any])?["result"] as? [String : Any])?["txnid"] as? String
        completion(responseParam as? [String : Any] ?? [:], transactionID ?? "NA", error)
    }
}

func createHashFor(source : String) -> String{
    var hash = sha512Hex(string: source)
    //var hash = HashCreator.createSHA512(source)
    hash = hash.replacingOccurrences(of: "<", with: "")
    hash = hash.replacingOccurrences(of: ">", with: "")
    return hash
    
    /*
     const char *cstr = [source cStringUsingEncoding:NSUTF8StringEncoding];
    NSData *data = [NSData dataWithBytes:cstr length:source.length];
    uint8_t digest[CC_SHA512_DIGEST_LENGTH];
    CC_SHA512(data.bytes, (CC_LONG)data.length, digest);
    NSMutableString* output = [NSMutableString  stringWithCapacity:CC_SHA512_DIGEST_LENGTH * 2];

    for(int i = 0; i < CC_SHA512_DIGEST_LENGTH; i++)
        [output appendFormat:@"%02x", digest[i]];
    
    NSString *hash =  [[[output stringByReplacingOccurrencesOfString:@"<" withString:@""]stringByReplacingOccurrencesOfString:@">" withString:@""]stringByReplacingOccurrencesOfString:@" " withString:@""];

    return hash;*/
}

func sha512Hex( string: String) -> String {
    var digest = [UInt8](repeating: 0, count: Int(CC_SHA512_DIGEST_LENGTH))
    if let data = string.data(using: String.Encoding.utf8) {
        let value =  data as NSData
        CC_SHA512(value.bytes, CC_LONG(data.count), &digest)

    }
    var digestHex = ""
    for index in 0..<Int(CC_SHA512_DIGEST_LENGTH) {
        digestHex += String(format: "%02x", digest[index])
    }

    return digestHex
}

==> flutter_payumoney_plugin-0.0.18.tar.gz: ios/Classes/PayUMoneyHelper.swift <==
//
//  PayUMoneyHelper.swift
//  PayUMoney Demo
//
//  Created by Akash Patel on 12/04/20.
//  Copyright © 2020 Akash Patel. All rights reserved.
//

import Foundation
import UIKit
import PayUMoneyCoreSDK
import PayUCustomBrowser
import PlugNPlay
import CommonCrypto

public func checkiOSLog(_ completion : @escaping (_ returnString : String)->Void) {
    DispatchQueue.main.asyncAfter(deadline: .now() + 2.0) {
        completion("checkiOSLog invoked")
    }
}

public func checkiOSReturn() -> String {
    return "checkiOSReturn"
}

public func startPaymentWithAmount(_ amount : String, userName : String, email: String, contactNo : String, formName: String, gNumber : String, isProduction : Bool, fromController : UIViewController, completion : @escaping (_ responseObject : [String : Any], _ transactionID : String, _ error : Error?)->Void) {
    
    let txnID = Int64(Date().timeIntervalSince1970 * 1000).description
    
    //Proceed with paymentprint(responseParam)
    let txnParam = PUMTxnParam.init()
    txnParam.phone = contactNo
    txnParam.email = email
    txnParam.amount = amount
    txnParam.environment = isProduction ? .production : .test
    txnParam.firstname = "\(userName) -\(gNumber)"
    txnParam.key = "cIzp948M"
    txnParam.merchantid = "5662740"
    txnParam.txnID = txnID
    txnParam.surl = "https://www.payumoney.com/mobileapp/payumoney/success.php"
    txnParam.furl = "https://www.payumoney.com/mobileapp/payumoney/failure.php"
    txnParam.productInfo = formName
    txnParam.udf1 = "Charged by Gujarat State Pharmacy Council"
    txnParam.udf2 = "Charged amount \(amount)"
    txnParam.udf3 = ""
    txnParam.udf4 = ""
    txnParam.udf5 = ""
    txnParam.udf6 = ""
    txnParam.udf7 = ""
    txnParam.udf8 = ""
    txnParam.udf9 = ""
    txnParam.udf10 = ""
    
    //cIzp948M|txnID123|\(self.textFieldAmount?.text ?? "1")|iPhone7|Akash|akashpatel116@gmail.com|||||||||||salt.
    //key|txnid|amount|productinfo|firstname|email|udf1|udf2|udf3|udf4|udf5||||||qoiFxDW2A2.
   // let createdHash = "cIzp948M|\(txnID)|\(amount)|\(UIDevice.current.model) with \(UIDevice.current.systemVersion)|\(userName)|\(email)|Charged by Gujarat State Pharmacy Council|Charged amount \(amount)|||||||||qoiFxDW2A2"
    let createdHash = "cIzp948M|\(txnID)|\(amount)|\(formName)|\(userName) -\(gNumber)|\(email)|Charged by Gujarat State Pharmacy Council|Charged amount \(amount)|||||||||qoiFxDW2A2"
    //"sha512(cIzp948M|txnID123|\(self.textFieldAmount?.text ?? "1")|iPhone7|Akash|akashpatel116@gmail.com|abc|5|||||||||qoiFxDW2A2)"
    txnParam.hashValue = createHashFor(source: createdHash)
    
    //key|txnid|amount|productinfo|firstname|email|udf1|udf2|udf3|udf4|udf5||||||qoiFxDW2A2"
    
    PlugNPlay.presentPaymentViewController(withTxnParams: txnParam, on: fromController) { (responseParam, error, anyObject) in
        print(responseParam)
        //self.lblTransactionID?.text = (responseParam as? NSDictionary)?.description
        print(error)
        print(anyObject)
        let transactionID = ((responseParam as? [String : Any])?["result"] as? [String : Any])?["txnid"] as? String
        completion(responseParam as? [String : Any] ?? [:], transactionID ?? "NA", error)
    }
}

func createHashFor(source : String) -> String{
    var hash = sha512Hex(string: source)
    //var hash = HashCreator.createSHA512(source)
    hash = hash.replacingOccurrences(of: "<", with: "")
    hash = hash.replacingOccurrences(of: ">", with: "")
    return hash
    
    /*
     const char *cstr = [source cStringUsingEncoding:NSUTF8StringEncoding];
    NSData *data = [NSData dataWithBytes:cstr length:source.length];
    uint8_t digest[CC_SHA512_DIGEST_LENGTH];
    CC_SHA512(data.bytes, (CC_LONG)data.length, digest);
    NSMutableString* output = [NSMutableString  stringWithCapacity:CC_SHA512_DIGEST_LENGTH * 2];

    for(int i = 0; i < CC_SHA512_DIGEST_LENGTH; i++)
        [output appendFormat:@"%02x", digest[i]];
    
    NSString *hash =  [[[output stringByReplacingOccurrencesOfString:@"<" withString:@""]stringByReplacingOccurrencesOfString:@">" withString:@""]stringByReplacingOccurrencesOfString:@" " withString:@""];

    return hash;*/
}

func sha512Hex( string: String) -> String {
    var digest = [UInt8](repeating: 0, count: Int(CC_SHA512_DIGEST_LENGTH))
    if let data = string.data(using: String.Encoding.utf8) {
        let value =  data as NSData
        CC_SHA512(value.bytes, CC_LONG(data.count), &digest)

    }
    var digestHex = ""
    for index in 0..<Int(CC_SHA512_DIGEST_LENGTH) {
        digestHex += String(format: "%02x", digest[index])
    }

    return digestHex
}
